<?php
 $title = 'Writing Contract Tracker: Add Commitment';

 $debug_out = '';

 require 'imports/utils.php';
 require 'imports/messages.php';
 $db_connection = null;

 $adding = array_key_exists('action', $_POST) && ($_POST['action'] == 'add');
 $success = false;
 
 if($adding)
  $db_connection = new contract_db();

 if($db_connection && $db_connection->working &&
  array_key_exists('id', $_POST) &&
  array_key_exists('contract_id', $_POST) &&
  array_key_exists('description', $_POST) &&
  date_input_exists('start', $_POST) &&
  array_key_exists('length_days', $_POST) &&
  array_key_exists('repeat_days', $_POST) &&
  array_key_exists('copies', $_POST))
 {
  $commitment_statement = $db_connection->prepare('INSERT INTO commitments (contract_id, description, start, length_days, repeat_days, daily_limit) VALUES (?, ?, ?, ?, ?, ?)');
  $task_statement = $db_connection->prepare('INSERT INTO tasks (commitment_id, start, done) VALUES (?, ?, 0)');

  $contract_id = (int)$_POST['contract_id'];
  $start_date = date_from_input('start', $_POST);
  $length_days = max((int)$_POST['length_days'], 1);
  $repeat_days = max((int)$_POST['repeat_days'], 1);
  $daily_limit = isset($_POST['daily_limit']) ? (int)$_POST['daily_limit'] : 0;

  $commitment_statement->bind_param('issiii', $contract_id, $_POST['description'], $start_date,
   $length_days, $repeat_days, $daily_limit);
  $commitment_statement->execute();
  $commitment_id = $db_connection->insert_id;

  // Tasks.
  $task_date = new simple_date($start_date);
  $contract_times = $db_connection->query('SELECT start, end FROM contracts WHERE id=' . $contract_id . ';')->fetch_assoc();
  $contract_start = new simple_date($contract_times['start']);
  $contract_end = new simple_date($contract_times['end']);

  while($task_date->lt($contract_start))
   $task_date->add_days($repeat_days);
   
  // Record our real start date.
  $simple_start = clone $task_date;

  while($task_date->lte($contract_end))
  {
   $copies = max(1, (int)$_POST['copies']);
   $task_date_string = (string)$task_date;
   $task_statement->bind_param('is', $commitment_id, $task_date_string);
   for($i = 0; $i < $copies; ++$i)
    $task_statement->execute();
   $task_date->add_days($repeat_days);
  }

  if($db_connection->errno)
   $db_connection->status = 'Failed to insert contract: ' . $db_connection->error;
  else
   $success = true;
 }
 // The add form, nothing has been added.
 else if(isset($_GET['id']) && isset($_GET['contract_id']))
 {
  $db_connection = new contract_db();
   
  $contracts = $db_connection->query('SELECT start FROM contracts WHERE id=' . (int)$_GET['contract_id'] . ';');
  if($contract = $contracts->fetch_row())
  {
   $start_date = new simple_date($contract[0]);
   
   if($db_connection->errno)
    $db_connection->status = 'Failed to insert contract: ' . $db_connection->error;
   else
    $success = true;
  }
 }

 if($success)
 {
  if($adding)
  {
  	message_commit_writer($db_connection, $commitment_id);
  	message_commit_monitor($db_connection, $commitment_id);
?>
   <p>Successfully added commitment!</p>
   <table>
    <tr><th>Task Description:</th><td><?=htmlspecialchars($_POST['description'])?></td></tr>
    <tr><th>Commitment Start Date:</th><td><?=$simple_start->prettyString()?></td></tr>
    <tr><th>Days to Finish:</th><td><?=htmlspecialchars($_POST['length_days'])?></td></tr>
    <tr><th>Days until task recurs:</th><td><?=htmlspecialchars($_POST['repeat_days'])?></td></tr>
    <tr><th>Copies:</th><td><?=htmlspecialchars($_POST['copies']);?></td></tr>
    <tr><th>Maximum of One Task Completion a Day:</th><td><?=isset($_POST['daily_limit']) ? 'True' : 'False';?></td></tr>
   </table>
<?php
  }
  else
  {
   require 'imports/top.php';
?>
   <form name="create_commitment" action="create_commitment.php" method="POST">
    <input type="hidden" name="id" value="<?=$_GET['id']?>" />
    <input type="hidden" name="contract_id" value="<?=$_GET['contract_id']?>" />
    <input type="hidden" name="action" value="add" />
    <table>
     <tr><th>Task Description:</th><td><input type="text" name="description" /></td></tr>
     <tr><th>Commitment Start Date:</th><td><?=date_input('start', $start_date);?></td></tr>
     <tr><th>Days to Finish:</th><td><input type="text" name="length_days" /></td></tr>
     <tr><th>Days until task recurs:</th><td><input type="text" name="repeat_days" /></td></tr>
     <tr><th>Copies:</th><td><input type="text" name="copies" value="1"/></td></tr>
     <tr><th>Maximum of One Task Completion a Day:</th><td><input type="checkbox" name="daily_limit" value="1"/></td></tr>
     <tr><th></th><td><input type="button" id="post_self" value="Create" /></td></tr>
    </table>
   </form>
<?php
   require 'imports/bottom.php';
  }
 }
 else
 {
  if(!$adding)
   require ' imports/top.php';
?>
  <p>Something went wrong.  Contact Edward and he'll try to fix it.</p>
<?php
  if(!$adding)
   require 'imports/bottom.php';
 }
?>