<?php
 $title = 'Writing Contract Tracker: Create Contract';
 
 require 'imports/utils.php';
 $db_connection = null;

 $adding = array_key_exists('action', $_POST) && ($_POST['action'] == 'add');
 $success = $adding ? false : array_key_exists('id', $_GET);
 
 if($adding)
  $db_connection = new contract_db(); 
 
 $start_date = null;
 $end_date = null;

 if($db_connection && $db_connection->working &&
  array_key_exists('id', $_POST) &&
  array_key_exists('name', $_POST) &&
  array_key_exists('description', $_POST) &&
  date_input_exists('start', $_POST) &&
  date_input_exists('end', $_POST) &&
  array_key_exists('vacations', $_POST) &&
  array_key_exists('vacations_used', $_POST) &&
  array_key_exists('allow_makeups', $_POST))
 {  
  $statement = $db_connection->prepare('INSERT INTO contracts (owner_id, name, description, start, end, vacations, vacations_used, allow_makeups) VALUES (?, ?, ?, ?, ?, ?, ?, ?)');

  $start_date = date_from_input('start', $_POST);
  $end_date = date_from_input('end', $_POST);

  $start_date_o = new simple_date($start_date);
  $end_date_o = new simple_date($end_date);

  if($start_date_o->lte($end_date_o))
  {
   $statement->bind_param('ssssssss', $_POST['id'], $_POST['name'], $_POST['description'], $start_date,
    $end_date, $_POST['vacations'], $_POST['vacations_used'], $_POST['allow_makeups']);
   $statement->execute();

   if($db_connection->errno)
    $db_connection->status = 'Failed to insert contract: ' . $db_connection->error;
   else
    $success = true;
  }
 }

 if($success)
 {
  if($adding)
  {
   $simple_start = new simple_date($start_date);
   $simple_end = new simple_date($end_date);
?>
   <p>Successfully added contract!</p>
   <table>
   <tr><th>Contract Name:</th><td><?=htmlspecialchars($_POST['name'])?></td></tr>
   <tr><th>Contract Description:</th><td><?=htmlspecialchars($_POST['description'])?></td></tr>
   <tr><th>Start Date:</th><td><?=$simple_start->prettyString()?></td></tr>
   <tr><th>End Date:</th><td><?=$simple_end->prettyString()?></td></tr>
   <tr><th>Total Vacations:</th><td><?=htmlspecialchars($_POST['vacations'])?></td></tr>
   <tr><th>Vacations Used at Contract Start:</th><td><?=htmlspecialchars($_POST['vacations_used'])?></td></tr>
   <tr><th>Allow Make-ups:</th><td><?=$_POST['allow_makeups'] ? 'Yes' : 'No'?></td></tr>
   </table>   
<?php
  }
  else
  {
   require 'imports/top.php';
   
   $today = new simple_date(date('Y-m-d'));
?>
   <form name="create_contract" action="create_contract.php" method="POST">
    <input type="hidden" name="id" value="<?=$_GET["id"]?>" />
    <input type="hidden" name="action" value="add" />
    <table>
    <tr><th>Contract Name:</th><td><input type="text" name="name" /></td></tr>
    <tr><th>Contract Description:</th><td><input type="text" name="description" /></td></tr>
    <tr><th>Start Date:</th><td><?=date_input('start', $today);?></td></tr>
    <tr><th>End Date:</th><td><?=date_input('end', $today);?></td></tr>
    <tr><th>Total Vacations:</th><td><input type="text" name="vacations" /></td></tr>
    <tr><th>Vacations Used at Contract Start:</th><td><input type="text" name="vacations_used" /></td></tr>
    <tr><th>Allow Make-ups:</th><td>
      <input type="radio" name="allow_makeups" value="1" id="makeups_true" checked="checked"/><label for="makeups_true">Yes</label>
      <input type="radio" name="allow_makeups" value="0" id="makeups_false"/><label for="makeups_false">No</label>
    </td></tr>
    <tr><th></th><td><input type="button" id="post_self" value="Create" /></td></tr>
    </table>
   </form>
<?php
   require 'imports/bottom.php';
  }
 }
 else
 {
  if(!$adding)
   require 'imports/top.php';
?>
  <p>Something went wrong.  Contact Edward and he'll try to fix it.</p>
<?php
  if(!$adding)
   require 'imports/bottom.php';
 }
?>