<?php
 // This in not intended to be a standalone web page, but instead to either be included
 //  by some other PHP page or be called via XMLHTTPRequest in order to fill in values on
 //  a page dynamically.

 // For this file we assume we are passed a database result $task which is an
 //  associative array with values: id(asks.id), commitment_id, start, length_days, description, daily_limit, last_day, and done.
 // If we are not then we must have a task_id POSTed to us, and we'll grab the rest.

 require_once 'utils.php';

 // Make sure we have a task to use if we've been called via XMLHTTPRequest
 if(!isset($task))
 {
  if($_POST && array_key_exists('task_id', $_POST))
   $task_id = $_POST['task_id'];
  else
  {
   echo 'ERROR: Can\'t get task in order to provide summary.';
   return;
  }
 }

  // Get a database accesor if we don't have one hanging around. We'll need one
  //  to continue.
 if(!isset($db_connection))
 {
  $db_connection = new contract_db();
  if(!$db_connection)
  {
   echo 'ERROR: No database connection.';
   return;
  }
 }

 // Now try to get a task, if we need to.
 if(!isset($task))
 {
  $query_string = 
      'SELECT tasks.id AS id, commitment_id, start, length_days, description, daily_limit, last_day, done, vacation FROM tasks ' .
      'INNER JOIN (SELECT id, description, length_days, daily_limit, last_day FROM commitments) AS current_commitments ' .
      'ON tasks.commitment_id=current_commitments.id ' .
      'WHERE tasks.id=' . (int)$task_id . ';';
  $task_result = $db_connection->query($query_string);

  if($task_result && ($task_result->num_rows > 0))
   $task = $task_result->fetch_assoc();
  else
  {
   echo 'ERROR: Could not get task information.' . "\n=" . $_POST['task_id'] . "=\n" . $query_string;
   return;
  }
 }

 // We now have a task to display, which unless we have a bug in other script code has
 //  the correct values.  Now we need to know if it can be completed, have a vacation used,
 //  or made up.  To do this we need to know if we're in the correct time to complete it,
 //  if we have any vacations left, and if make ups are allowed,   We only need to get the
 //  last two, from our contract.
 if(!isset($contract))
 {
  $contract_result = $db_connection->query(
   'SELECT end, vacations, vacations_used, allow_makeups FROM ' .
   '(contracts INNER JOIN (' .
   'SELECT * FROM commitments WHERE commitments.id=' . $task['commitment_id'] .
   ') AS commitment ON commitment.contract_id=contracts.id);');

   if($contract_result && ($contract_result->num_rows > 0))
    $contract = $contract_result->fetch_assoc();
   else
   {
    echo 'ERROR: Could not get contract information.';
    return;
   }
 }

 // Check if we should have buttons.
 if(!isset($show_buttons))
  if($_POST && array_key_exists('show_buttons', $_POST))
   $show_buttons = (int)$_POST['show_buttons'];

 // Remember now, if we don't already.
 if(!isset($today))
  $today = new simple_date(date('Y-m-d'));

 // Just remember these.
 $task_start = new simple_date($task['start']);
 $task_end = clone $task_start;
 $task_end->add_days($task['length_days'] - 1);
 $contract_end = new simple_date($contract['end']);
 $last_completion = (($task['daily_limit'] > 0) && ($task['last_day'] != null)) ?
  new simple_date($task['last_day']) : null; 
 if($contract_end->lt($task_end))
  $task_end = $contract_end;

 // We've got all the information we need, output it.
?>
<div class="task_summary" id="task_summary<?=$task['id'];?>">
 <table>
  <tr><th>Task Description:</th><td><?=htmlspecialchars($task['description']);?></td></tr>
  <tr><th>Start Date:</th><td><?=$task_start->prettyString();?></td></tr>
  <tr><th>Deadline:</th><td><?=$task_end->prettyString();?></td></tr>
 </table>
<?php
 $button_string = '';
 if($show_buttons)
 {
  if(!$today->lt($task_start))
  {
   if(!$task['done'])
   {
    if($today->lte($task_end))
    {
     if(!$last_completion || $last_completion->lt($today))
      $button_string .= '<input type="button" name="done" class="task_button" value="Done!"/>';
    }
    else if($contract['allow_makeups'])
     $button_string .= '<input type="button" name="make_up" class="task_button" value="Make Up"/>';
     
    if($contract['vacations_used'] < $contract['vacations'])
     $button_string .= '<input type="button" name="vacation" class="task_button" value="Use Vacation"/>';
   }
   else if($task['vacation'] && $contract['allow_makeups'])
   {
    $button_string .= '<input type="button" name="make_up_vacation" class="task_button" value="Make Up Vacation"/>';
   }
  }

  // Get our options to see if we should display delete buttons.
  $delete_info = $db_connection->query('SELECT option_allow_delete, c.id FROM people as p ' .
   'INNER JOIN contracts AS cc INNER JOIN commitments AS c INNER JOIN tasks AS t ' .
   'ON t.commitment_id=c.id AND c.contract_id=cc.id AND cc.owner_id=p.id ' .
   'WHERE t.id=' . $task['id'] . ';')->fetch_assoc();
  if($delete_info['option_allow_delete'])
  {
   $button_string .= '<input type="button" name="delete_task" class="delete_task" id="delete_task' .
    $task['id'] . '" value="Delete Task"/>';
   $button_string .= '<input type="button" name="delete_commitment" class="delete_commitment" id="delete_commitment' .
    $delete_info['id'] . '" value="Delete Commitment"/>';
  }

  if(strlen($button_string) > 0)
   echo '<form>' . $button_string . '</form>';
 }
?>
</div>
