<?php
 mb_internal_encoding('UTF-8');
 mb_http_output('UTF-8');
 mb_http_input('UTF-8');
 mb_language('uni');
 mb_regex_encoding('UTF-8');
 ob_start('mb_output_handler');

 ini_set('display_errors', 'On');
 error_reporting(E_ALL | E_STRICT);

 date_default_timezone_set('America/Los_Angeles');

 require_once 'config.php';
 require_once 'error_handler.php';

 class contract_db extends mysqli
 {
  public $status = '';
  public $working = false;

  function __construct()
  {
   $create_people = 'CREATE TABLE people' .
                    '(' .
                    '  id INT AUTO_INCREMENT,' .
                    '  name_first VARCHAR(256),' .
                    '  name_last VARCHAR(256),' .
                    '  email VARCHAR(256),' .
                    '  monitor_email VARCHAR(256),' .
                    '  option_one_week TINYINT,' .
                    '  option_show_future TINYINT,' .
                    '  option_separate_weeks TINYINT,' .
                    '  option_separate_commitments TINYINT,' .
                    '  option_allow_delete TINYINT,' .
                    '  option_fail_mail TINYINT,' .
                    '  option_auto_vacation TINYINT,' .
                    '  PRIMARY KEY (id)' .
                    ');';
   $create_contracts = 'CREATE TABLE contracts' .
                    '(' .
                    '  id INT AUTO_INCREMENT,' .
                    '  owner_id INT,' .
                    '  name VARCHAR(4096),' .
                    '  description VARCHAR(4096),' .
                    '  start DATE,' .
                    '  end DATE,' .
                    '  vacations INT,' .
                    '  vacations_used INT,' .
                    '  allow_makeups TINYINT,' .
                    '  PRIMARY KEY(id),' .
                    '  FOREIGN KEY (owner_id) REFERENCES people (id)' .
                    ');';
   $create_commitments = 'CREATE TABLE commitments' .
                    '(' .
                    '  id INT AUTO_INCREMENT,' .
                    '  contract_id INT,' .
                    '  description VARCHAR(1024),' .
                    '  start DATE,' .
                    '  length_days INT,' .
                    '  repeat_days INT,' .
                    '  daily_limit INT,' .
                    '  last_day DATE,' .
                    '  PRIMARY KEY(id),' .
                    '  FOREIGN KEY (contract_id) REFERENCES contracts (id)' .
                    ');';
   $create_tasks = 'CREATE TABLE tasks' .
                    '(' .
                    '  id INT AUTO_INCREMENT,' .
                    '  commitment_id INT,' .
                    '  start DATE,' .
                    '  done TINYINT,' .
                    '  vacation TINYINT,' .
                    '  PRIMARY KEY(id),' .
                    '  FOREIGN KEY (commitment_id) REFERENCES commitments (id)' .
                    ');';
   $create_tables = array($create_people, $create_contracts, $create_commitments, $create_tasks);

   // We'll change these if we have to.
   $this->working = true;
   $this->status = 'Success, created!';
   parent::__construct(DB_HOST, DB_USER, DB_PASSWORD);
   $create_database = false;
   if($this->connect_errno)
   {
    if($this->connect_errno == 2)
     $create_database = true;
    else
    {
     $this->status = 'Could not connect: ' . $this->connect_error;
     $this->working = false;
    }
   }
   else
   {
    if(!$this->query('USE ' . DB_DATABASE . ';'))
    {
      $create_database = true;
    }
    else
    {
     $table_test = $this->query('SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME="people"');
     if($table_test->num_rows > 0)
     {
      $this->working = true;
      $this->status = 'Success, connected!';
     }
     else
      $create_tables_flag = true;
    }
   }
   
   if($create_database)
   {
    if(!$this->query('CREATE DATABASE ' . DB_DATABASE . ';'))
    {
     $this->status = 'CREATE failed: ' . $this->error;
     $this->working = false;
    }
    else
     $create_tables_flag = true;
   }
   
   if(isset($create_tables_flag))
   {
    if(!$this->query('USE ' . DB_DATABASE . ';'))
    {
     $this->status = 'Could not connect: ' . $this->error;
     $this->working = false;
    }
    else
    {
     foreach($create_tables as $create_table)
     {
      if(!$this->query($create_table))
      {
       $this->status = 'Failed to create tables: ' . $this->error;
       $this->working = false;
       break;
      }
     }
    }
   }
  }

  function __destruct()
  {
   if(method_exists('mysqli', '__destruct'))
    parent::__destruct();
  }
 }

 class simple_date
 {
  public static $days_per_month = array(31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
  public static $month_names = array('January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December');
  public static $day_names = array('Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday', 'Sunday');
  public $year;
  public $month; // 1 based, not 0.
  public $day; // 1 based, not 0.

  function __construct($sql_date_string)
  {
   sscanf($sql_date_string, '%d-%d-%d', $this->year, $this->month, $this->day);
  }

  function __toString()
  {
   return $this->year . '-' . $this->month . '-' . $this->day;
  }

  function prettyString()
  {
    return self::$day_names[$this->day_of_week()] . ' ' .
     self::$month_names[$this->month - 1] . ' ' . $this->day . ', ' . $this->year;
  }

  function lt($other_date)
  {
   if($this->year < $other_date->year)
   {
     return true;
   }
   else if($this->year == $other_date->year)
   {
    if($this->month < $other_date->month)
    {
     return true;
    }
    else if($this->month == $other_date->month)
    {
     return $this->day < $other_date->day;
    }
   }

   return false;
  }

  function lte($other_date)
  {
   return !$other_date->lt($this);
  }

  function add_days($days)
  {
    $next_day = $this->day + $days;
    $max_day = $this->days_in_month();

    while($next_day > $max_day)
    {
     $next_day -= $max_day;
     ++$this->month;
     if($this->month > 12)
     {
      $this->month = 1;
      ++$this->year;
     }
     $max_day = $this->days_in_month();
    }

    $this->day = $next_day;
  }

  function subtract_days($days)
  {
   $this->day -= $days;
   while($this->day < 1)
   {
      --$this->month;
      if($this->month < 1)
      {
        --$this->year;
        $this->month = 12;
      }
      $this->day += $this->days_in_month();
   }
  }

  private function days_in_month()
  {
   if($this->month != 2)
    return self::$days_per_month[$this->month - 1];
   else if((($this->year % 4) == 0) && ((($this->year % 100) != 0) || (($this->year % 400) == 0)))
	 return self::$days_per_month[$this->month - 1] + 1;
	else
	 return self::$days_per_month[1]; // $this->month - 1
  }

  // 0 based day of week.  Monday is 0.
  public function day_of_week()
  {
   // Get the days to January 1st of the year, counting up leap years.
   //  Actually, we count even the current year if it's a leap year, which
   //  we'll correct later.  Also, we add 365 days from year 0 to year 1 which,
   //  again, we'll correct below.
   $days = ($this->year * 365) + floor($this->year / 4) - floor($this->year / 100) + floor($this->year / 400);

   // Modify if this year is a leap year. We've counted it above, so remove if too early in the year.
   if(($this->month < 3) && (($this->year % 4) == 0) && ((($this->year % 100) != 0) || (($this->year % 400) == 0)))
    --$days;

   // Modify for month.
   for($i = 1; $i < $this->month; ++$i)
    $days += self::$days_per_month[$i - 1];

   // Now add for the current day.  Remember, 1 based.
   $days += $this->day - 1;
   
   // January 1, 1 AD was a Monday, which means we should just be able
   //  to mod with 7 to get a 0 based day of the week (Monday is 0),
   //  but we have an extra 365 days as we just multiply the year by
   //  365 above, not counting there was no year 0 (so no days have
   //  passed to get us to year 1) resulting in 365 extra days.  So
   //  as 365 % 7 = 1 we're one day ahead, and we have to remove it.
   //  we do that by adding 6 prior to moding with 7.
   return ($days + 6) % 7;
  }

  // Get next monday.
  public function next_monday()
  {
   $to_return = clone($this);
   $to_return->add_days(7 - $this->day_of_week());
   return $to_return;
  }
  
  // Get monday of the current week.
  public function this_monday()
  {
   $to_return = clone($this);
   $to_return->subtract_days($this->day_of_week());
   return $to_return;
  }
 }

 // Very simple, we don't do any real validation at the moment.
 function date_input($postfix, $start_date = null)
 {
  ob_start();
?>
   <div class="date_input">
    <select name="dateInputMonth_<?=$postfix;?>" id="dateInputMonth_<?=$postfix;?>">
<?php
      for($i = 1; $i < 13; ++$i)
      {
        echo '<option value="' . $i . '"' .
         ((($start_date != null) && ($i == $start_date->month)) ? ' selected="selected"' : '') .
         '>' . simple_date::$month_names[$i - 1] . '</option>';
       }
?>
    </select>
    <select name="dateInputDay_<?=$postfix;?>" id="dateInputDay_<?=$postfix;?>">
<?php
    for($i = 1; $i <= 31; ++$i)
    {
?>
      <option value="<?=$i;?>"<?=(($start_date != null) && ($i == $start_date->day)) ? ' selected="selected"' : '' ?>><?=$i;?></option>
<?php
    }
?>
    </select>,
    <select name="dateInputYear_<?=$postfix;?>" id="dateInputYear_<?=$postfix;?>">
<?php
    for($i = 2012; $i <= 2030; ++$i)
    {
?>
      <option value="<?=$i;?>"<?=(($start_date != null) && ($i == $start_date->year)) ? ' selected="selected"' : '' ?>><?=$i;?></option>
<?php
    }
?>
    </select>
   </div>
<?php
  $result = ob_get_contents();
  ob_end_clean();

  return $result;
 }

 function date_input_exists($postfix, $dateArray)
 {
  return array_key_exists("dateInputMonth_" . $postfix, $dateArray) &&
   array_key_exists("dateInputDay_" . $postfix, $dateArray) &&
   array_key_exists("dateInputYear_" . $postfix, $dateArray);
 }

 function date_from_input($postfix, $dateArray)
 {
  if(date_input_exists($postfix, $dateArray))
  {
   return ((int)($dateArray["dateInputYear_" . $postfix])) . "-" .
    ((int)($dateArray["dateInputMonth_" . $postfix])) . "-" .
    ((int)($dateArray["dateInputDay_" . $postfix]));
  }
  else
   return null;
 }
?>