// Brings up a summary when the correct node is clicked.
function summaryClick(event)
{
  var request = createRequest();

  var caller = getActivatedObject(event);
  var task_id = caller.getAttribute("id").substr(4); // "task#"

  var finder = /\btask_summary\b/;

  var container = caller.parentNode;
  for(var task_container = container.firstChild;
   task_container != null;
   task_container = task_container.nextSibling)
  {
    var attr;
    if((task_container.nodeType == 1) &&
      (attr = task_container.getAttribute("class")) &&
      finder.test(attr))
    {
      break;
    }
  }

  if(!task_container)
    return;

  var task_div = caller;
  request.onreadystatechange = function(event)
  {
    if((this.readyState != 4) || (this.status != 200))
      return;

    task_container.innerHTML = this.responseText;
    var parent = task_container.parentNode;
    var selected = getElementsByClass("selected", parent);
    for(var i = 0; i < selected.length; ++i)
    {
      selected[i].className = selected[i].className.replace(/\bselected\b/, "");
    }
    task_div.className += " selected";

    registerTaskButtonPressedFactory(task_container)();
    registerDeleteCommitmentFactory(task_container)();
    registerDeleteTaskFactory(task_container)();
  }

  request.open("POST", "imports/task_info.php", true);
  request.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
  enqueueRequest(request, "task_id=" + task_id + "&show_buttons=1");
}

// Function to register summary click events.
function registerSummaryClick()
{
  var summaries = getElementsByClass("summary_image");
  for(var i = 0; i < summaries.length; ++i)
    addEventHandler(summaries[i], "click", summaryClick, true);
}

// React to some task button being pressed.
function taskButtonPressed(e)
{   
  var target = getActivatedObject(e);
  
  // We know our page structure, so we can easily find the proper elements.
  for(var task_div =  target.parentNode; task_div; task_div = task_div.parentNode)
    if(task_div.id && task_div.id.match(/^task_summary\d+$/))
      break;

  var task_id = Number(task_div.id.match(/\d+/)[0]);

  // Disable our buttons.
  var buttons = task_div.getElementsByTagName('input');
  for(var i = 0; i < buttons.length; ++i)
    buttons[i].disabled = true;
 
  var request = createRequest();

  request.onreadystatechange = function() {
    if(request.readyState != 4)
      return;

    // Our buttons should be re-enabled.
    var buttons = task_div.getElementsByTagName('input');
    for(var i = 0; i < buttons.length; ++i)
      buttons[i].disabled = false;

    if(request.status != 200)
      return;

    if(request.responseText == 'failed')
      return;

    // Update our image.
    var task_marker = document.getElementById('task' + task_id);
    removeClass(task_marker, 'missed_image'); // May not have this, but no harm.
    removeClass(task_marker, 'current_image'); // May not have this, but no harm.
    removeClass(task_marker, 'vacation_image'); // May not have this, but no harm.
    if(request.responseText == 'vacation')
      task_marker.className += ' vacation_image';
    else
      task_marker.className += ' done_image';

    // Remove our buttons.
    var forms = task_div.getElementsByTagName('form');
    for(var i = forms.length - 1; i >= 0; --i)
      forms[i].parentNode.removeChild(forms[i]);

    // Update vacations.
    if((request.responseText == 'vacation') || request.responseText == 'make_up_vacation') {
       var contract_div = task_div.parentNode;
       while(contract_div.className != 'contract')
         contract_div = contract_div.parentNode;

       var vacations = getElementsByClass("vacation_data", contract_div);
       var scanner = /(\d+)\/(\d+)/;
       for(var i = 0; i < vacations.length; ++i) { // Should only be 1, but whatevs.
         var result = scanner.exec(vacations[i].innerHTML);
         if(request.responseText == 'vacation')
           vacations[i].innerHTML = (Number(result[1]) + 1) + "/" + result[2];
         else
           vacations[i].innerHTML = (Number(result[1]) - 1) + "/" + result[2];
       }

      // We may need another button.  Let the server figure it out.  For now
      //  we'll just send a fake event.  This relies heavily on the structure of
      //  summaryClick so may blow up in our faces.
      summaryClick({target: task_marker});
    }

    document.getElementById("status").innerHTML = request.responseText;
  }

  request.open("POST", "task_button.php", true);
  request.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
  enqueueRequest(request, "request_type=" + target.name + "&task_id=" + task_id);
}

// Function to register commitment button click events.
function registerTaskButtonPressedFactory(context)
{
  return function() {
    var task_buttons = getElementsByClass("task_button", context);
    for(var i = 0; i < task_buttons.length; ++i)
      addEventHandler(task_buttons[i], "click", taskButtonPressed, true);
  }
}

// Checkbox option handlers.
function checkboxOptionChanged(e) {
  var target = getActivatedObject(e);

  var parameters = getURLParameters();

  var request = createRequest();
  
  request.onreadystatechange = function() {
     if(request.readyState != 4)
       return;

     if(request.status != 200)
       return;
       
    // TODO: Mark as success or failure.
  }
  
  request.open("POST", "options.php?id=" + parameters["id"]);
  request.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
  enqueueRequest(request, "option=" + target.name + "&value=" + (target.checked ? 1 : 0));  
}

function registerCheckboxOptionChanged() {
  var inputs = document.getElementsByTagName("input");

  for(var i = 0; i < inputs.length; ++i) {
    if((inputs[i].type == "checkbox") && (inputs[i].name.search("option_") == 0)) {
      addEventHandler(inputs[i], "change", checkboxOptionChanged, true);
    }
  }
}

function textOptionChanged(e)
{
  var target = getActivatedObject(e);
  var extraData = getExtraData(target);

  var parameters = getURLParameters();

  if('timeout' in extraData) {
    window.clearTimeout(extraData.timeout);
    delete extraData.timeout;
  } 
  
  extraData.timeout = window.setTimeout(function() {
    delete extraData.timeout;
     
    var request = createRequest();
    
    request.onreadystatechange = function() {
      if(request.readyState != 4)
        return;

      if(request.status != 200)
        return;
       
      // TODO: Mark as success or failure.
    }
  
    request.open("POST", "options.php?id=" + parameters["id"]);
    request.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
    enqueueRequest(request, "option=" + target.name + "&value=" + encodeURIComponent(target.value));
  }, 1000);
}

function registerTextOptionChanged() {
  var inputs = document.getElementsByTagName("input");

  for(var i = 0; i < inputs.length; ++i) {
    if((inputs[i].type == "text") && (inputs[i].name.search("option_") == 0)) {
      addEventHandler(inputs[i], "keypress", textOptionChanged, true);
    }
  }
}

function deleteContract(e) {
  var target = getActivatedObject(e);
  
  var finder = /\bcontract\b/;

  var container = target.parentNode;
  while(container && !finder.test(container.className))
    containter = container.parentNode;

  if(!container)
    return;

  var id = Number(container.id.match(/\d+/)[0]);
  
  if(confirm("This will permanently remove the contract.  Only continue if you're sure this is what you want."))
  {
    var request = createRequest();
    
    request.onreadystatechange = function() {
      if(request.readyState != 4)
        return;

      if(request.status != 200)
        return;
       
      window.location.reload(true);
    }
  
    request.open("POST", "delete_data.php");
    request.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
    enqueueRequest(request, "id=" + id + "&type=contract");
  }
}

function registerDeleteContract() {
  var buttons = getElementsByClass("delete_contract");
  
  for(var i = 0; i < buttons.length; ++i)
    addEventHandler(buttons[i], "click", deleteContract, true);
}

function deleteCommitment(e) {
  var target = getActivatedObject(e);
  
  var id = Number(target.id.match(/\d+/)[0]);
  
  if(confirm("This will permanently remove the commitment this task belongs to, " +
   "along with all tasks which are part of it including this one. " +
   "Only continue if you're sure this is what you want."))
  {
    var request = createRequest();
    
    request.onreadystatechange = function() {
      if(request.readyState != 4)
        return;

      if(request.status != 200)
        return;
       
      window.location.reload(true);
    }
  
    request.open("POST", "delete_data.php");
    request.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
    enqueueRequest(request, "id=" + id + "&type=commitment");
  }
}

function registerDeleteCommitmentFactory(context) {
   
  return function() {
    var buttons = getElementsByClass("delete_commitment", context);
  
    for(var i = 0; i < buttons.length; ++i)
      addEventHandler(buttons[i], "click", deleteCommitment, true);
  }
}

function deleteTask(e) {
  var target = getActivatedObject(e);
  
  var id = Number(target.id.match(/\d+/)[0]);
  
  if(confirm("This will permanently remove this task. " +
   "Only continue if you're sure this is what you want."))
  {
    var request = createRequest();
    
    request.onreadystatechange = function() {
      if(request.readyState != 4)
        return;

      if(request.status != 200)
        return;
       
      window.location.reload(true);
    }
  
    request.open("POST", "delete_data.php");
    request.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
    enqueueRequest(request, "id=" + id + "&type=task");
  }
}

function registerDeleteTaskFactory(context) {
   
  return function() {
    var buttons = getElementsByClass("delete_task", context);
  
    for(var i = 0; i < buttons.length; ++i)
      addEventHandler(buttons[i], "click", deleteTask, true);
  }
}

// Add event handlers.
addEventHandler(window, "load", registerSummaryClick, true);
addEventHandler(window, "load", registerTaskButtonPressedFactory(), true);
addEventHandler(window, "load", registerCheckboxOptionChanged, true);
addEventHandler(window, "load", registerTextOptionChanged, true);
addEventHandler(window, "load", registerDeleteContract, true);
addEventHandler(window, "load", registerDeleteCommitmentFactory(), true);
addEventHandler(window, "load", registerDeleteTaskFactory(), true);
