<?php
 ini_set('display_errors', 'On');
 error_reporting(E_ALL | E_STRICT);
 $title = 'Writing Contract Tracker: Summary';
 $select_summary_nav = true;

 // Simple utility which allows us to place a string between
 //  two strings in output.
 class split_writer
 {
  private $output_array = array();

  function add($pre_string, $post_string = null)
  {  
     $this->output_array[] = $pre_string;
     if($post_string != null)
     {
      $to_return = count($this->output_array);
      $this->output_array[] = '';
      $this->output_array[] = $post_string;
      return $to_return;
     }
  }

  function replace($index, $value)
  {
   $this->output_array[$index] = $value;
  }

  function output()
  {
   return implode($this->output_array);
  }
  
  function pos()
  {
   return count($this->output_array);
  }
  
  function head($position)
  {
   $this->output_array = array_slice($this->output_array, 0, $position);
  }
 }

 require_once 'imports/utils.php';
 $db_connection = new contract_db();

 $user = array_key_exists('id', $_GET) ? (int)$_GET['id'] : null;
 $summary = null;
 if($db_connection->working && $user)
 {
  $people = $db_connection->query('SELECT * FROM people WHERE id=' . $user . ';');
  $person = ($people->num_rows > 0) ? $people->fetch_assoc() : null;
  $contracts = $db_connection->query('SELECT * FROM contracts WHERE owner_id=' . $user . ' ORDER BY end DESC, start ASC;');
  if($contracts && ($contracts->num_rows > 0))
  {
   ob_start();
   while($contract = $contracts->fetch_assoc())
   {
    $simple_start = new simple_date($contract['start']);
    $simple_end = new simple_date($contract['end']);
?>
    <div class="contract" id="contract<?=$contract['id'];?>">
     <h2>Contract: <?=htmlspecialchars($contract['name']);?></h2>
     <p><?=htmlspecialchars($contract['description']);?></p>
     <table>
      <tr><th>Start:</th><td><?=$simple_start->prettyString();?></td></tr>
      <tr><th>End:</th><td><?=$simple_end->prettyString();?></td></tr>
      <tr><th>Vacations Used:</th><td class="vacation_data"><?=$contract['vacations_used'];?>/<?=$contract['vacations'];?></td></tr>
     </table>
     <h3>Task List</h3>
<?php
     $today = new simple_date(date('Y-m-d'));
     if($person['option_one_week'])
     {
      $week_start = $today->this_monday();
      $week_end = $today->next_monday();
     }
     else
     {
      unset($week_start);
      unset($week_end);
     }
     $first_current_task = null;
     $fallback_selection = null;
     $fb_index = null;
     $sw = new split_writer();

     if($person['option_separate_commitments'])
     {
       $commitments = $db_connection->query(
        'SELECT id, description FROM commitments WHERE contract_id=' . (int)$contract['id'] . ';');
     }
     else
      unset($commitments);

     // Actually, if we don't have $commitments then we'll break after one iterataion.
     while(!isset($commitments) || ($commitment = $commitments->fetch_assoc()))
     {
      if(isset($commitments))
      {
       $tasks = $db_connection->query(
        'SELECT tasks.id AS id, commitment_id, start, length_days, description, daily_limit, last_day, done, vacation FROM tasks ' .
        'INNER JOIN (SELECT id, description, length_days, daily_limit, last_day FROM commitments ' .
        'WHERE id=' . (int)$commitment['id'] .') AS current_commitments ' .
        'ON tasks.commitment_id=current_commitments.id ORDER BY tasks.start, description, commitment_id ASC;');
        
        $sw_commitment_start = $sw->pos();
        $sw->add('<h4>' . htmlspecialchars($commitment['description']) . '</h4>');
        $sw_list_start = $sw->pos();
      }
      else
      {
       $tasks = $db_connection->query(
        'SELECT tasks.id AS id, commitment_id, start, length_days, description, daily_limit, last_day, done, vacation FROM tasks ' .
        'INNER JOIN (SELECT id, description, length_days, daily_limit, last_day FROM commitments ' .
        'WHERE contract_id=' . (int)$contract['id'] .') AS current_commitments ' .
        'ON tasks.commitment_id=current_commitments.id ORDER BY tasks.start, description, commitment_id ASC;');
      }

      while($task = $tasks->fetch_assoc())
      {
       $start = new simple_date($task['start']);

       if(isset($week_start))
       {
        if($start->lt($week_start))
         continue;
        else if($week_end->lt($start))
         break;
       } 

       if($person['option_separate_weeks'])
       {
        if(!isset($next_monday))
        {
         $next_monday = $start->next_monday();
        }
        else if(!$start->lt($next_monday) &&
         ($start->lte($today) || $person['option_show_future']))
        {
         $sw->add('<div class="commitment_week"></div>');
         $next_monday = $start->next_monday();  
        }
       }
      
       if($start->lte($today))
       {
        $task_in_list = true;
        $fallback_selection = $task;
        $end = clone $start;
        $end->add_days($task['length_days'] - 1);

        if($task['done'])
        {
        	if($task['vacation'])
        	 $fb_index = $sw->add('<div class="summary_image vacation_image', '" id="task' . $task['id'] . '"></div>');
        	else
          $fb_index = $sw->add('<div class="summary_image done_image', '" id="task' . $task['id'] . '"></div>');
        }
        else if($end->lt($today))
         $fb_index = $sw->add('<div class="summary_image missed_image', '" id="task' . $task['id'] . '"></div>');
        else
        {
         if(!$first_current_task)
         {
          $first_current_task = $task;
          $sw->add('<div class="summary_image current_image selected" id="task' . $task['id'] . '"></div>');
         }
         else
          $sw->add('<div class="summary_image current_image" id="task' . $task['id'] . '"></div>');
        }
       }
       else
       {
        if(!$person['option_show_future'])
         break;
        
        $task_in_list = true; 
        if(!$fallback_selection)
        {
         $fallback_selection = $task;
         $fb_index = $sw->add('<div class="summary_image future_image', '" id="task' . $task['id'] . '"></div>');
        }
        else
         $sw->add('<div class="summary_image future_image" id="task' . $task['id'] . '"></div>');
       }
      }

      if(isset($next_monday))
       unset($next_monday);

      // If we don't have $commitments then only go through this loop once.
      if(!isset($commitments))
       break;
      else if($sw_list_start == $sw->pos())
      {
       $sw->head($sw_commitment_start);
      }
      else
       $sw->add('<div class="clear"></div>');
     }

     if(!$first_current_task && $fallback_selection)
      $sw->replace($fb_index, ' selected');

     if(!isset($task_in_list))
      $sw->add('No tasks to list.');
     else
      unset($task_in_list);

     echo $sw->output();
?>
     <div class="clear"></div>
     <a href="create_commitment.php?id=<?=$user;?>&contract_id=<?=$contract['id'];?>">Add Commitment</a>
     <h3>Selected Task Details</h3>
<?php
     // Show summary for our first unfinished, but finishable, task.
     if($first_current_task || $fallback_selection)
     {
      if($first_current_task)
       $task = $first_current_task;
      else
       $task = $fallback_selection;
      $show_buttons = true;
      include 'imports/task_info.php';
     }
     else
      echo '<div class="task_summary">No task selected.</div>';
?>
     <div class='clear'></div>
<?php
     if($person['option_allow_delete'])
     {
?>
     <input type="button" name="delete_contract" class="delete_contract" value="Delete Contract"/>
     <div class='clear'></div>
<?php
     }
?>
    </div>
<?php
   }

   $summary = ob_get_contents();
   ob_end_clean();
  }
 }

 require 'imports/top.php';
?>
<div id="contracts">
 <div id="legend">
  <table>
   <tr><th class="table_title">Legend</th><th>Missed</th><th>Done</th><th>Vacationed</th><th>Current</th><th>Future</th></tr>
   <tr><th>Unselected</th><td><div class="legend_image missed_image"/></td><td><div class="legend_image done_image"/></td><td><div class="legend_image vacation_image"/></td><td><div class="legend_image current_image"/></td><td><div class="legend_image future_image"/></td></tr>
   <tr><th>Selected</th><td><div class="legend_image missed_image selected"/></td><td><div class="legend_image done_image selected"/></td><td><div class="legend_image vacation_image selected"/></td><td><div class="legend_image current_image selected"/></td><td><div class="legend_image future_image selected"/></td></tr>
  </table>
 </div>
<?php
 if($summary)
 {
  echo $summary;
  if(strlen($summary) > 0)
  {
   echo '<div id="create_spacer"></div>';
  }
 }
?>
<a href="create_contract.php?id=<?=$user;?>">Create new contract.</a>
</div>
<?php

 require 'imports/bottom.php';
?>

